@@ -67,7 +67,6 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.metastatic.rsync.ChecksumPair;
 import org.metastatic.rsync.Rdiff;
-import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.MultipleAdapterServletNew;
 import com.openexchange.ajax.helper.DownloadUtility;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
@@ -79,7 +78,6 @@ import com.openexchange.file.storage.json.actions.files.AJAXInfostoreRequest;
 import com.openexchange.file.storage.json.actions.files.AbstractFileAction;
 import com.openexchange.file.storage.json.actions.files.FileActionFactory;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.mail.mime.ContentType;
 import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.session.ServerSession;
@@ -104,24 +102,14 @@ public class FileServlet extends MultipleAdapterServletNew {
     static {
         final Map<String, Handler> m = new HashMap<String, Handler>(4);
         m.put("document", new Handler() {
-
-            /** Attempts to set a sanitized <code>Content-Type</code> header value to given HTTP response. */
-            private void trySetSanitizedContentType(final String contentType, final HttpServletResponse resp) {
-                try {
-                    resp.setContentType(new ContentType(contentType).getBaseType());
-                } catch (final Exception e) {
-                    // Ignore
-                    resp.setContentType(contentType);
-                }
-            }
             
             public void handle(final AJAXRequestData data, final HttpServletRequest req, final HttpServletResponse res, final ServerSession session) throws IOException, AbstractOXException {
                 final AJAXInfostoreRequest request = new AJAXInfostoreRequest(data, session);
                 request.require(AbstractFileAction.Param.ID);
 
-                final String contentType = AJAXServlet.encodeUrl(req.getParameter(PARAMETER_CONTENT_TYPE), true);
-                final String userAgent = AJAXServlet.sanitizeParam(req.getHeader("user-agent"));
-                final String contentDisposition = AJAXServlet.encodeUrl(req.getParameter(PARAMETER_CONTENT_DISPOSITION));
+                final String contentType = req.getParameter(PARAMETER_CONTENT_TYPE);
+                final String userAgent = req.getHeader("user-agent");
+                final String contentDisposition = req.getParameter(PARAMETER_CONTENT_DISPOSITION);
 
                 final IDBasedFileAccess fileAccess = request.getFileAccess();
                 final File fileMetadata = fileAccess.getFileMetadata(request.getId(), request.getVersion());
@@ -137,9 +125,12 @@ public class FileServlet extends MultipleAdapterServletNew {
                             DownloadUtility.appendFilenameParameter(fileMetadata.getFileName(), SAVE_AS_TYPE, userAgent, sb);
                             res.setHeader("Content-Disposition", sb.toString());
                         } else {
-                            Tools.setHeaderForFileDownload(userAgent, res, fileMetadata.getFileName(), contentDisposition);
+                            final StringBuilder sb = new StringBuilder(32).append(contentDisposition.trim());
+                            DownloadUtility.appendFilenameParameter(fileMetadata.getFileName(), SAVE_AS_TYPE, userAgent, sb);
+                            res.setHeader("Content-Disposition", sb.toString());
+                            // Tools.setHeaderForFileDownload(userAgent, res, fileMetadata.getFileName(), contentDisposition);
                         }
-                        trySetSanitizedContentType(contentType, res);
+                        res.setContentType(contentType);
                     } else {
                         final com.openexchange.ajax.helper.DownloadUtility.CheckedDownload checkedDownload =
                             DownloadUtility.checkInlineDownload(
@@ -164,7 +155,7 @@ public class FileServlet extends MultipleAdapterServletNew {
                             res.setHeader("Content-Disposition", checkedDownload.getContentDisposition());
                         }
                         if (contentType != null) {
-                            trySetSanitizedContentType(contentType, res);
+                            res.setContentType(contentType);
                         } else {
                             res.setContentType(checkedDownload.getContentType());
                         }
